import request from "@/utils/request";
// const api = "/mosty-jcgl";
const api = "/mosty-api/mosty-jcgl";
// 分页查询
export function getTbJcglBq(params) {
  return request({
    url: api + '/tbJcglBq',
    method: 'GET',
    params
  })
}
//新增
export function addTbJcglBq(data) {
  return request({
    url: api + '/tbJcglBq',
    method: "post",
    data
  })
}
//修改
export function putTbJcglBq(data) {
  return request({
    url: api + '/tbJcglBq',
    method: "put",
    data
  })
}
//详情
export function infoTbJcglBq(id) {
  return request({
    url: api + `/tbJcglBq/${id}`,
    method: "get"
  })
}
//删除
export function delTbJcglBq(id) {
  return request({
    url: api + `/tbJcglBq/${id}`,
    method: "DELETE"
  })
}
/**
 * 注销标签
 * @param {*} params
 * @returns
 */
 export const deleteTbJcglBq = (data) => {
  return request({
    url: `${api}/tbJcglBq/zcbqByIds`,
    method: "put",
    data
  });
};